==> V01.54.zip: tweet_live-V01.54/web/eduinnov-conference/config.php <==
<?php
$config = array(
    'tracking_keywords' => array('#eduinnov'),
    'hashtag'    => '#eduinnov #salleConf',
    'date'       => '28-29.03.2012',
    'heure'      => '09h30-17h30',
    'place'      => 'Unesco (Paris)',
    'duration'   => '',

    'title'      => "Journées de l'innovation",
                        
    'abstract'   => "<b>Journées de l'innovation</b><br/> 14 / 03 / 2012 de 18h00 à 20h00 @ Centre Pompidou (Paris)",

    'description'=> "
    <h3>Programme de la Salle XII (#SalleConf)</h3>
    <h3>28 mars 2012</h3>
    <p><b>9h30-11h00&nbsp;: Conférences inaugurales</b></p>
    <ul>
        <li><b>Jean Audouze</b>, président de la Commission nationale française pour l'Unesco.</li>
        <li><b>Jean-Michel Blanquer</b>, directeur général de l'enseignement scolaire.</li>
    </ul>
    <p><b>Conférences introductives</b></p>
    <ul>
        <li><b>Garry Kasparov</b></li>
        <li><b>François Taddei</b>, directeur de recherche à l’INSERM, faculté de médecine Necker, Paris.</li>
    </ul>
    <p><b>11h30-13h00&nbsp;: La recherche au service des apprentissages de demain</b></p>
    <ul>
        <li><b>Bruno della Chiesa</b>, analyste principal, CERI/OCDE.</li>
        <li><b>Anthony Salcito</b>, vice-président, Microsoft, responsable éducation, États-Unis.</li>
    </ul>
    <p><b>13h30-15h00&nbsp;: Organisation apprenante et changement des pratiques professionnelles en éducation</b></p>
    <ul>
        <li><b>Monica Gather-Thurler</b>, professeur, laboratoire Innovation-Formation-Éducation (LIFE), université de Genève</li>
        <li><b>Chinezi Chijioke</b>, directeur de projet, Johannesbourg, et «&nbsp;Education leader&nbsp;» pour l’Afrique, McKinsey & Company</li>
    </ul>
    <p><b>16h30-17h30&nbsp;: Conduire le changement par l’innovation</b></p>
    <ul>
        <li><b>Marie-Jeanne Philippe</b>, rectrice de l’académie de Lille</li>
        <li><b>Nathalie Bulle</b>, directrice de recherche au CNRS, Groupe d’Étude des Méthodes de l’Analyse Sociologique de la Sorbonne (GEMASS)</li>
    </ul>
    <p><b>17h30&nbsp;: Remise de prix</b></p>
    <ul>
        <li><b>Prix du partenariat</b>, remis par Suzy Halimi, vice-présidente de la Commission nationale française pour l’UNESCO</li>
    </ul>
    <h3>29 mars 2012</h3>
    <p><b>9h30-11h00&nbsp;: Apprendre, stratégies et incertitudes</b></p>
    <ul>
        <li><b>Romuald Normand</b>, maître de conférences-HDR, Laboratoire Triangle, ENS Lyon-Institut français d’éducation</li>
        <li><b>Edgar Morin</b>, écrivain, philosophe, sociologue, actuellement directeur de recherche émérite au CNRS</li>
    </ul>
    <p><b>11h15&nbsp;: Remise de prix</b></p>
    <ul>
        <li><b>Prix Edgar Morin</b>, remis par Edgar Morin.</li>
    </ul>
    <p><b>13h30-15h00&nbsp;: Apprendre de l’expérience</b></p>
    <ul>
        <li><b>Martin Hirsch</b>, président de l’Agence du service civique</li>
        <li><b>Tracey Burns</b>, analyste, CERI/OCDE</li>
    </ul>
    <p><b>15h15-16h30&nbsp;: Remise de prix</b></p>
    <ul>
        <li><b>Prix du public</b>, remis par Garry Kasparov</li>
        <li><b>Prix de l’évaluation</b>, remis par Catherine Ferrant, déléguée générale de la Fondation Total et Yann Dyèvre, directeur de la jeunesse, de l’éducation populaire et de la vie associative</li>
        <li><b>Prix des usagers</b>, remis par François-Daniel Migeon, directeur général de la modernisationde l’État</li>
    </ul>",

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/les-journees-de-linnovation/?lang=fr_fr',
   	'islive_embed'     => '<iframe frameborder="0" width="{{width}}" height="{{height}}" src="http://www.dailymotion.com/embed/video/xpdcce?logo=0&autoPlay=1&forcedQuality=hq"></iframe>',
   	'keywords'   => '"éducation, innovation, conférence, focus, unesco"',
   	'rep' 		 => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.education.gouv.fr/'
class='footerLink' target='_blank'> Ministère de l'&Eacute;ducation Nationale </a>
|  <a href='http://www.unesco.org/'
class='footerLink' target='_blank'> UNESCO </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => "images/client_visual.jpg", // 501 × 376 pixels
    
 	'head_logo' => 'images/logo_head.png', // 171 × 63 pixels
 	
  	'slide_background' => "images/slider_home.png", // 606 × 282 pixels
    
  	'archive_img' => "images/archive_img.jpg", // 270 × 150 pixels

    'archive_title' => "Journées de l'innovation - Salle XII (#SalleConference)",
    'archive_description' => "par <a href=\"http://www.education.gouv.fr/\" target=\"_blank\">Ministère de l'&Eacute;ducation Nationale</a> à l'UNESCO<br/> les 28 et 29 mars 2012 | 09:30 - 17:30",

    // After the event
	'metadata'		=> "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'duration'  	=> 10876600,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);

==> V01.94.zip: tweet_live-V01.94/web/eduinnov-conference/config.php <==
<?php
$config = array(
    'tracking_keywords' => array('#eduinnov', '#eduinov'),
    'hashtag'    => '#eduinov #salleConf',
    'date'       => '28-29.03.2012',
    'heure'      => '09h30-17h30',
    'place'      => 'Unesco (Paris)',
    'duration'   => '',

    'title'      => "Journées de l'innovation",
    'abstract'   => "<b>Journées de l'innovation</b><br/> les 28 et 29 / 03 / 2012 de 9h30 à 17h20 à l'Unesco (Paris)",

    'description'=> "
    <h3>Programme de la Salle XII (#SalleConf)</h3>
    <h3>28 mars 2012</h3>
    <p><b>9h30-11h00&nbsp;: Conférences inaugurales</b></p>
    <ul>
        <li><b>Jean Audouze</b>, président de la Commission nationale française pour l'Unesco.</li>
        <li><b>Jean-Michel Blanquer</b>, directeur général de l'enseignement scolaire.</li>
    </ul>
    <p><b>Conférences introductives</b></p>
    <ul>
        <li><b>Garry Kasparov</b></li>
        <li><b>François Taddei</b>, directeur de recherche à l’INSERM, faculté de médecine Necker, Paris.</li>
    </ul>
    <p><b>11h30-13h00&nbsp;: La recherche au service des apprentissages de demain</b></p>
    <ul>
        <li><b>Bruno della Chiesa</b>, analyste principal, CERI/OCDE.</li>
        <li><b>Anthony Salcito</b>, vice-président, Microsoft, responsable éducation, États-Unis.</li>
    </ul>
    <p><b>13h30-15h00&nbsp;: Organisation apprenante et changement des pratiques professionnelles en éducation</b></p>
    <ul>
        <li><b>Monica Gather-Thurler</b>, professeur, laboratoire Innovation-Formation-Éducation (LIFE), université de Genève</li>
        <li><b>Chinezi Chijioke</b>, directeur de projet, Johannesbourg, et «&nbsp;Education leader&nbsp;» pour l’Afrique, McKinsey & Company</li>
    </ul>
    <p><b>16h30-17h30&nbsp;: Conduire le changement par l’innovation</b></p>
    <ul>
        <li><b>Marie-Jeanne Philippe</b>, rectrice de l’académie de Lille</li>
        <li><b>Nathalie Bulle</b>, directrice de recherche au CNRS, Groupe d’Étude des Méthodes de l’Analyse Sociologique de la Sorbonne (GEMASS)</li>
    </ul>
    <p><b>17h30&nbsp;: Remise de prix</b></p>
    <ul>
        <li><b>Prix du partenariat</b>, remis par Suzy Halimi, vice-présidente de la Commission nationale française pour l’UNESCO</li>
    </ul>
    <h3>29 mars 2012</h3>
    <p><b>9h30-11h00&nbsp;: Apprendre, stratégies et incertitudes</b></p>
    <ul>
        <li><b>Romuald Normand</b>, maître de conférences-HDR, Laboratoire Triangle, ENS Lyon-Institut français d’éducation</li>
        <li><b>Edgar Morin</b>, écrivain, philosophe, sociologue, actuellement directeur de recherche émérite au CNRS</li>
    </ul>
    <p><b>11h15&nbsp;: Remise de prix</b></p>
    <ul>
        <li><b>Prix Edgar Morin</b>, remis par Edgar Morin.</li>
    </ul>
    <p><b>13h30-15h00&nbsp;: Apprendre de l’expérience</b></p>
    <ul>
        <li><b>Martin Hirsch</b>, président de l’Agence du service civique</li>
        <li><b>Tracey Burns</b>, analyste, CERI/OCDE</li>
    </ul>
    <p><b>15h15-16h30&nbsp;: Remise de prix</b></p>
    <ul>
        <li><b>Prix du public</b>, remis par Garry Kasparov</li>
        <li><b>Prix de l’évaluation</b>, remis par Catherine Ferrant, déléguée générale de la Fondation Total et Yann Dyèvre, directeur de la jeunesse, de l’éducation populaire et de la vie associative</li>
        <li><b>Prix des usagers</b>, remis par François-Daniel Migeon, directeur général de la modernisationde l’État</li>
    </ul>",

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/les-journees-de-linnovation/?lang=fr_fr',
   	'islive_embed'     => '<iframe frameborder="0" width="{{width}}" height="{{height}}" src="http://www.dailymotion.com/embed/video/xpdcce?logo=0&autoPlay=1&forcedQuality=hq"></iframe>',
   	'keywords'   => '"éducation, innovation, conférence, focus, unesco"',
   	'rep' 		 => basename('__DIR__'),
   	'partenaires'=> "<a href='http://www.education.gouv.fr/'
class='footerLink' target='_blank'> Ministère de l'&Eacute;ducation Nationale </a>
|  <a href='http://www.unesco.org/'
class='footerLink' target='_blank'> UNESCO </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => "images/client_visual.jpg", // 501 × 376 pixels
    
 	'head_logo' => 'images/logo_head.png', // 171 × 63 pixels
 	
  	'slide_background' => "images/slider_home.png", // 606 × 282 pixels
    
  	'archive_img' => "images/archive_img.jpg", // 270 × 150 pixels

    'archive_title' => "Journées de l'innovation - Salle XII (#SalleConference)",
    'archive_description' => "par <a href=\"http://www.education.gouv.fr/\" target=\"_blank\">Ministère de l'&Eacute;ducation Nationale</a> à l'UNESCO<br/> les 28 et 29 mars 2012 | 09:30 - 17:30",

    // After the event
	'metadata'		=> "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'duration'  	=> 10876600,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);
